<?php

/**
 * Plugin Name: NEOMAIL
 * Plugin URI: https://neo-vps.com
 * Description: VPS-NEO用のHTMLメール、ステップメール原稿作成のためのプラグイン
 * Version: 1.4
 * Author: N.Kamita / PRJAPAN
 * Author URI: https://prjapan.co.jp
 * バリデーションアップ履歴
 * 1.1 おすすめCSSのコピー追加
 * 1.2 コメントタグの間違い
 * 1.3 非表示設定修正　カテゴリー名は非表示できない 外部ブロック機能をつけた
 * 1.4 ZipArchiveが使えない場合のエラメッセージを追加
 */

//
// 機種依存文字変換ライブラリ
//
require_once 'CharacterEncoding.php';

use App\Libs\CharacterEncoding;

//
// メニュー作成
//
// Add menu pages in dashboard menu
function stepneo_menu()
{
    add_menu_page('NEOMAIL', 'NEOMAIL', 'manage_options', 'stepneo_category_settings', 'stepneo_category_settings_page', 'dashicons-admin-users', 0);
    add_submenu_page('stepneo_category_settings', 'CSS設定', 'CSS設定', 'manage_options', 'stepneo_css_settings', 'stepneo_css_settings_page');
    add_submenu_page('stepneo_category_settings', '外部ブロック設定', '外部ブロック設定', 'manage_options', 'stepneo_block_settings', 'stepneo_block_page');
}
add_action('admin_menu', 'stepneo_menu');


//
// メインメニュー
//
// Callback function for category settings page
function stepneo_category_settings_page()
{
    global $wpdb;
    // Check if user has sufficient permissions
    if (!current_user_can('manage_options')) {
        wp_die('You do not have sufficient permissions to access this page.');
    }
    // code for category settings page
    // Link to display the HTML file
    echo '<h3><a href="' . plugins_url('exp1.html', __FILE__) . '" target="_blank">説明はこちら</a></h3>';
    echo "<h2>VPS-NEO用のHTMLメール、ステップメール原稿作成のためのプラグイン</h2>";
    echo "<h3>ステップメールの編集用のカテゴリーを選択してください</h3>";
    echo "<p>チェックしたカテゴリーは、外部(管理者以外)に対して非表示になります。</p>";


    // Save category settings
    if (isset($_POST['submit'])) {
        $excluded_cats = array();
        $categories = get_categories('hide_empty=0');
        foreach ($categories as $cat) {
            $cat_id = $cat->cat_ID;
            if (isset($_POST['cat_' . $cat_id])) {
                $excluded_cats[] = $cat_id;
            }
        }
        update_option('stepneo_excluded_cats', $excluded_cats);
    }

    // Get excluded categories
    $excluded_cats = get_option('stepneo_excluded_cats', array());

    // Display category list
    $categories = get_categories('hide_empty=0');
    echo '<form method="post">';
    echo '<ul>';
    foreach ($categories as $cat) {
        $cat_id = $cat->cat_ID;
        $checked = in_array($cat_id, $excluded_cats) ? 'checked' : '';
        $cateCount = get_category($cat_id)->count;
        echo '<li style="margin:5px;padding:5px">';
        echo '<input type="checkbox" name="cat_' . $cat_id . '" ' . $checked . '>';
        echo $cat->cat_name;
        echo "(" . $cateCount . ")";
        if ($checked == "checked") {
            echo '<a href="' . admin_url('admin-ajax.php?action=stepneo_download&cat_id=' . $cat_id) . '" style="margin-left: 20px;border: 1px solid;padding: 5px;font-weight:bold">ステップメール原稿取得</a>';
        }
        echo '</li>';
    }
    echo '</ul>';
    echo '<input type="submit" name="submit" value="Save">';
    echo '</form>';
}



//
// 説明HTMLへのクリック表示
//
// Function to redirect to the HTML file
function display_html_file()
{
    wp_redirect(plugins_url('exp1.html', __FILE__));
    exit;
}

// Action to call the function
add_action('wp_ajax_display_html_file', 'display_html_file');



//
// CSS設定メニュー　保存と反映
//
// Callback function for CSS settings page
function stepneo_css_settings_page()
{
    global $wpdb;
    // Check if user has sufficient permissions
    if (!current_user_can('manage_options')) {
        wp_die('You do not have sufficient permissions to access this page.');
    }
    // code for CSS settings page
    echo "<h3>ステップメールに反映するCSS(HTMLメールのデザイン)を設定してください</h3>";

    // Check if form has been submitted
    if (isset($_POST['submit']) && $_POST['css'] != '') {
        // Get the CSS from the form
        //$css = sanitize_textarea_field( $_POST['css'] );
        $css = $_POST['css'];
        $css = str_replace(array('<style>', '</style>'), '', $css);

        // CSS スタイルシートを配列に分割する
        $css_array = explode("}", $css);

        // CSS スタイルシートを連想配列に格納する
        $styles = array();
        foreach ($css_array as $style) {
            $style = trim($style);
            if (!empty($style)) {
                list($selector, $properties) = explode("{", $style);
                $selector = trim($selector);
                $properties = trim($properties);
                $styles[$selector] = $properties;
            }
        }

        //print_r($styles);
        // Validate the CSS
        $valid = true;
        foreach ($styles as $selector => $properties) {
            // Check if selector is valid
            if (!preg_match('/^[a-zA-Z0-9,.\#:\[\]\s >\"\']+$/', $selector)) {
                unset($styles[$selector]);
            }
            // Check if properties are valid
            if (!preg_match('/^[a-zA-Z0-9:\s.;\#,\-%()#]+$/', $properties)) {
                unset($styles[$selector]);
            }
        }


        if ($valid) {
            // Update the options in the database
            update_option('stepneo_css', $css);

            // Show a success message
            echo '<div class="updated"><p>CSS has been updated successfully.</p></div>';
        } else {
            // Show an error message
            echo '<div class="error"><p>CSSの形式ではありません。</p></div>';
        }
    }

    // Get the saved CSS
    $css = get_option('stepneo_css', '');

    $css_default = get_css();



    // Display the form
    echo '<h3>HTMLメールに反映したいCSSを入力</h3>';
    echo "<p>複雑な書き方のCSS部分は削除されます。</p>";
    echo "<p><button id='css_copy'>おすすめCSSのコピー</button><p>";
    echo '<form method="post">';
    echo '<textarea id="cssarea" cols="50" rows="20" name="css">' . esc_textarea($css) . '</textarea><br>';
    echo '<textarea id="cssdefault" cols="50" rows="20" name="css" style="display:none;">' . esc_textarea($css_default) . '</textarea><br>';
    echo '<input type="submit" name="submit" value="Save">';
    echo '</form>';
    echo '<script>
  document.getElementById("css_copy").addEventListener("click", function() {
    document.getElementById("cssarea").value = document.getElementById("cssdefault").value;
  });
</script>';
}

//管理人以外のブロックメニュー
function stepneo_block_page() {
  if ( ! current_user_can( 'manage_options' ) ) {
    wp_die( 'You do not have sufficient permissions to access this page.' );
  }
  $step_admin_only = get_option( 'step_admin_only' );
  if ( isset( $_POST['submit'] ) ) {
    if ( isset( $_POST['step_admin_only'] ) ) {
      $step_admin_only = 1;
    } else {
      $step_admin_only = 0;
    }
    update_option( 'step_admin_only', $step_admin_only );
        $message_html = <<<EOF
        <div class="notice notice-info">
        <p>更新しました</p>
        </div>
        EOF;
    echo $message_html;
  }
  ?>
  <div class="wrap">
    <h1>外部ブロック設定</h1>
    <form method="post" action="">
      <p>このワードプレスを第三者から完全にブロックし、管理者だけが使えるようにするのであれば、以下にチェックしてください。</p>
      <p>
        <input type="checkbox" id="step_admin_only" name="step_admin_only" value="1" <?php checked( $step_admin_only, 1 ); ?> />
        <label for="step_admin_only">管理者専用のワードプレスとする</label>
      </p>
      <p>
        <input type="submit" name="submit" id="submit" class="button button-primary" value="更新">
      </p>
    </form>
  </div>
  <?php
}

//管理人以外は、ログインページに飛ばす

/*
Plugin Name: Step Admin Only
Description: Redirects non-admin users to the login page if step_admin_only is set to 1 in the wp_options table.
*/

add_action( 'init', 'redirect_to_login_if_step_admin_only' );
function redirect_to_login_if_step_admin_only() {
  if ( strpos( $_SERVER['PHP_SELF'], 'wp-login.php' ) !== false ) {
    return;
  }
  $step_admin_only = get_option( 'step_admin_only' );
  //$step_admin_only = 1;
  if ( $step_admin_only == 1 && (! current_user_can( 'manage_options' ) || ! is_user_logged_in()) ) {
    wp_redirect( wp_login_url() );
    exit;
  }
}



//
// ステップメール原稿のカテゴリー毎全ダウンロード
//
// Download function for selected category
function stepneo_download()
{

    if(!class_exists(ZipArchive)){
      echo "必要なZIP機能がこのサーバーにインストールされていないので、利用できません。プラグインの方で代替手段を検討しています。<br>原稿取得は、各記事ページを表示させた場合の「ダウンロード」ボタンからしてください。";
      exit;
    }

    global $wpdb;
    // Get category ID
    $cat_id = $_GET['cat_id'];

    // Get posts in category
    $posts = get_posts(array(
        'category' => $cat_id,
        'numberposts' => -1
    ));

    // Set headers for zip file
    $zipname = 'category_' . $cat_id . '.zip';
    header('Content-Type: application/zip');
    header('Content-Disposition: attachment; filename="' . $zipname . '"');

    // Create zip file and add post contents
    $zip = new ZipArchive;
    $zip->open($zipname, ZipArchive::CREATE);

    // Keep track of processed posts
    $processed_posts = array();

    // Readme content
    $readme = "ステップメール用原稿作成処理結果\n\n";

    foreach ($posts as $post) {
        // Get post meta values
        $step_id = get_post_meta($post->ID, 'step_id', true);
        $stepday = get_post_meta($post->ID, 'stepday', true);
        $sendtime = get_post_meta($post->ID, 'sendtime', true);

        // Check if step_id is set
        if (!$step_id) {
            $readme .= $post->post_title . "\n" .
                "Result: NG (step_id not set)\n\n";

            $readme .= "------------------------\n";
            continue;
        }

        // Check if step_id is unique
        if (in_array($step_id, $processed_posts)) {
            $readme .= $post->post_title . "\n" .
                "Result: NG (step_id is not unique)\n\n";

            $readme .= "------------------------\n";
            continue;
        }

        // Add post to processed posts
        $processed_posts[] = $step_id;

        // Format post content
        $content = "# import file format\n" .
            "version=1\n" .
            "step_id=" . $step_id . "\n" .
            "Name=" . $stepday . "日目\n" .
            "stepday=" . $stepday . "\n" .
            "sendtime=" . $sendtime . "\n" .
            "Title=" . $post->post_title . "\n\n" .
            make_text($post->post_content) . "\n\n" .
            "__BELOW_THIS_LINE_IS_HTMLBODY__\n" .
            make_html($post->post_content);

        // Add post content to zip file
        $zip->addFromString($step_id . '.txt', $content);

        // Add post to readme

        // Add post to readme
        $result = "OK";
        if (!isset($step_id) || empty($step_id)) {
            $result = "NG - step_id not found";
        }
        $readme .= "{$post->post_title} / {$result}\n";
        $readme .= "File name: {$step_id}.txt\n";
        $readme .= "Step ID: {$step_id}\n";
        $readme .= "Step Day: {$stepday}\n";
        $readme .= "Send Time: {$sendtime}\n";
        $readme .= "------------------------\n";
    }
    $zip->addFromString('readme.txt', $readme);
    $zip->close();



    // Output the zip file
    readfile($zipname);
    unlink($zipname);
    exit;
}

add_action('wp_ajax_stepneo_download', 'stepneo_download');
add_action('wp_ajax_nopriv_stepneo_download', 'stepneo_download');


//
// ステップメールのカテゴリーは外部非表示
//
function stepneo_exclude_categories($query)
{
    // Get excluded categories
    $excluded_cats = get_option('stepneo_excluded_cats', array());

    // Only modify the main query
    if ($query->is_main_query()) {
        // Check if current user is not an administrator
        if (!current_user_can('manage_options') || !is_user_logged_in()) {
            // Exclude posts in excluded categories
            $query->set('category__not_in', $excluded_cats);
            // Only retrieve posts from categories that are not excluded
            $query->set('cat', implode(',', get_all_category_ids_except($excluded_cats)));
        }
    }
}

function get_all_category_ids_except($excluded_cats)
{
    $categories = get_categories();
    $included_cats = array();
    foreach ($categories as $category) {
        if (!in_array($category->term_id, $excluded_cats)) {
            $included_cats[] = $category->term_id;
        }
    }
    return $included_cats;
}

add_action('pre_get_posts', 'stepneo_exclude_categories');



//
// サイトのどこにもステップメールのカテゴリーは名前も非表示にする
//    
function exclude_categories_from_get_categories($args)
{
    if (!current_user_can('manage_options') || !is_user_logged_in()) {
        $excluded_cats = get_option('stepneo_excluded_cats', array());
        if (!empty($excluded_cats)) {
            $args['exclude'] = implode(',', $excluded_cats);
        }
    }
    return $args;
}

add_filter('get_categories', 'exclude_categories_from_get_categories');





//
// ステップメールに設定したカテゴリーの記事編集画面にステップメール設定を出す
//

function stepneo_add_meta_box()
{
    $excluded_cats = get_option('stepneo_excluded_cats', array());
    $current_post_cat = get_the_category();
    $current_post_cat_id = $current_post_cat[0]->cat_ID;

    // Check if the current post's category is not excluded
    if (in_array($current_post_cat_id, $excluded_cats)) {
        add_meta_box('stepneo_settings', 'ステップメールの設定', 'stepneo_render_meta_box', 'post', 'side', 'high');
    }
}
add_action('add_meta_boxes', 'stepneo_add_meta_box');




//
// 設定メタボックスの内容
//

function stepneo_render_meta_box($post)
{
    // Get post meta values
    $step_id = get_post_meta($post->ID, 'step_id', true);
    $stepday = get_post_meta($post->ID, 'stepday', true);
    $sendtime = get_post_meta($post->ID, 'sendtime', true);

    // Render form fields
?>
    <table class="form-table">
        <tbody>
            <tr>
                <th><label for="step_id">Step ID</label></th>
                <td>
                    <input type="number" name="step_id" id="step_id" value="<?php echo esc_attr($step_id); ?>">
                    <p>ダウンロード時のファイル番号になります</p>
                </td>
            </tr>
            <tr>
                <th><label for="stepday">Step Day</label></th>
                <td>
                    <input type="number" name="stepday" id="stepday" value="<?php echo esc_attr($stepday); ?>">
                    <p>ステップメールを送る日</p>
                </td>
            </tr>
            <tr>
                <th><label for="sendtime">Send Time</label></th>
                <td>
                    <input type="text" name="sendtime" id="sendtime" value="<?php echo esc_attr($sendtime); ?>">
                    <p>メール送信時間(例　10:5)</p>
                </td>
            </tr>
        </tbody>
    </table>
<?php
}


//
// メタボックス内容の保存
//

function save_stepmail_settings_meta_box_data($post_id)
{
    /*
    
        // Verify nonce
        if ( ! isset( $_POST['stepmail_settings_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['stepmail_settings_meta_box_nonce'], 'stepmail_settings_meta_box' ) ) {
            return;
        }
        // Check if the user has permissions to save data
        if ( ! current_user_can( 'edit_post', $post_id ) ) {
            return;
        }
        // Check if it's not an autosave
        if ( wp_is_post_autosave( $post_id ) ) {
            return;
        }
        // Check if it's not a revision
        if ( wp_is_post_revision( $post_id ) ) {
            return;
        }

    */
    // Validate and sanitize input data
    $step_id = isset($_POST['step_id']) ? intval($_POST['step_id']) : '';
    $stepday = isset($_POST['stepday']) ? intval($_POST['stepday']) : '';
    $sendtime = isset($_POST['sendtime']) ? sanitize_text_field($_POST['sendtime']) : '';
    if ($stepday == "0") {
        $stepday = "1";
    }
    // Save the data
    update_post_meta($post_id, 'step_id', $step_id);
    update_post_meta($post_id, 'stepday', $stepday);
    update_post_meta($post_id, 'sendtime', $sendtime);
}
add_action('save_post', 'save_stepmail_settings_meta_box_data');


/**
 * HTMLソースを配列として、タグなどを削除してテキストにする
 * @param string
 * @return string
 */
function make_text($html)
{

    $charEncoding = new CharacterEncoding();
    $html = $charEncoding->replaceMachineChar($html);

    // HTML中のコメント部分を削除する正規表現を定義する
    //$pattern = '/<!--(.|\s)*?-->/';
    $pattern = '/<!--(.|\s)*?-->\s*(\r\n|\r|\n)?/';

    // HTML中のコメント部分を削除する
    $html = preg_replace($pattern, '', $html);

    //<br>は改行にする
    $html = str_replace("<br>", "\n", $html);

    $html = strip_tags($html);

    $html = preg_replace('/^ +/m', '', $html);

    //
    //$html=preg_replace("/\n/m","",$html);
    $html = preg_replace('/(\r\n|\r|\n){2,}/', "\n\n", $html);

    return $html;
}


//
// 原稿用HTMLの整形
//
function make_html($html)
{

    $charEncoding = new CharacterEncoding();
    $html = $charEncoding->replaceMachineChar($html);


    // HTML中のコメント部分を削除する正規表現を定義する
    //$pattern = '/<!--(.|\s)*?-->/';
    $pattern = '/<!--(.|\s)*?-->\s*(\r\n|\r|\n)?/';

    // HTML中のコメント部分を削除する
    $html = preg_replace($pattern, '', $html);

    $css = get_option('stepneo_css', '');

    // CSS スタイルシートを配列に分割する
    $css_array = explode("}", $css);

    // CSS スタイルシートを連想配列に格納する
    $styles = array();
    foreach ($css_array as $style) {
        $style = trim($style);
        if (!empty($style)) {
            list($selector, $properties) = explode("{", $style);
            $selector = trim($selector);
            $properties = trim($properties);
            $styles[$selector] = $properties;
        }
    }

    // HTML 文字列から要素を取得して、CSS スタイルを挿入する
    foreach ($styles as $selector => $properties) {
        $html = preg_replace("/<$selector\b/i", "<$selector style='$properties'", $html);
    }

    // 変換された HTML 文字列を返す
    return $html;
}




function exclude_categories_from_widget($args)
{
    $excluded_cats = get_option('stepneo_excluded_cats', array());
    if (!empty($excluded_cats)) {
        $args['exclude'] = implode(',', $excluded_cats);
    }
    return $args;
}

add_filter('widget_categories_args', 'exclude_categories_from_widget');


function exclude_category_title($title)
{
    if (!current_user_can('manage_options')) {
        $excluded_cats = get_option('stepneo_excluded_cats', array());
        $post_categories = wp_get_post_categories(get_the_ID());
        $intersect = array_intersect($post_categories, $excluded_cats);
        if (!empty($intersect)) {
            return '非表示';
        }
    }
    return $title;
}
//他にも影響があり使えない
//add_filter('the_title', 'exclude_category_title');





// ページごとのダウンロード
//
add_action('the_content', 'download_buttons_on_post', 20);
function download_buttons_on_post($content)
{
    $post = get_post();

    if (!current_user_can('manage_options')) {
        $categories = get_the_category($post->ID);
        $excluded_cats = get_option('stepneo_excluded_cats', array());

        foreach ($categories as $category) {
            if (in_array($category->cat_ID, $excluded_cats)) {
                return 'このページは非表示コンテンツです。閲覧できません。';
            }
        }

        return $content;
    }


    // Get post meta values
    $step_id = get_post_meta($post->ID, 'step_id', true);
    $stepday = get_post_meta($post->ID, 'stepday', true);
    $sendtime = get_post_meta($post->ID, 'sendtime', true);


    $txt = make_text($post->post_content);
    $html = make_html($post->post_content);

    // Format post content
    $stepmailtxt = "# import file format\n" .
        "version=1\n" .
        "step_id=" . $step_id . "\n" .
        "Name=" . $stepday . "日目\n" .
        "stepday=" . $stepday . "\n" .
        "sendtime=" . $sendtime . "\n" .
        "Title=" . $post->post_title . "\n\n" .
        $txt . "\n\n" .
        "__BELOW_THIS_LINE_IS_HTMLBODY__\n" .
        $html;


    $buttons = '<div class="download-buttons">';
    $buttons .= '<a class="button txt-download" href="data:text/plain;charset=utf-8,' . rawurlencode($txt) . '" download="' . get_the_title() . '.txt">テキストダウンロード</a>';
    $buttons .= '<a class="button html-download" href="data:text/html;charset=utf-8,' . rawurlencode($html) . '" download="' . get_the_title() . '.html">HTMLダウンロード</a>';
    $buttons .= '<a class="button txt-download" href="data:text/plain;charset=utf-8,' . rawurlencode($stepmailtxt) . '" download="' . get_the_title() . 'forstepmail.txt">ステップメール用インポート原稿</a>';
    $buttons .= '</div>';


    $buttons .= '<textarea class="txt-data" style="display: none;">' . $txt . '</textarea>';
    $buttons .= '<textarea class="html-data" style="display: none;">' . $html . '</textarea>';
    $buttons .= '<script>
  document.querySelector(".txt-download").addEventListener("click", function(event) {
    //event.preventDefault();
    var txtData = document.querySelector(".txt-data").value;
    navigator.clipboard.writeText(txtData).then(function() {
      alert("テキストをクリップボードにコピーしました");
    });
  });
  document.querySelector(".html-download").addEventListener("click", function(event) {
    //event.preventDefault();
    var htmlData = document.querySelector(".html-data").value;
    navigator.clipboard.writeText(htmlData).then(function() {
      alert("HTMLをクリップボードにコピーしました");
    });
  });
</script>';

    return $buttons . $content;
}


//
// ダウンロードボタンのCSS
//
add_action('wp_head', 'add_download_buttons_css');
function add_download_buttons_css()
{
    if (!is_single() || !current_user_can('manage_options')) {
        return $content;
    }
    echo '<style>
    .download-buttons .button {
      display: inline-block;
      margin: 10px;
      padding: 10px 20px;
      background-color: #333;
      color: #fff;
      text-decoration: none;
      border-radius: 5px;
    }
  </style>';
}

function get_css()
{

    $default_css = <<<EOF
			
body {
  font-family: Arial, sans-serif;
  background-color: #f5f5f5;
  color: #333333;
  font-size: 16px;
  line-height: 1.5;
}
h1 {
  margin: 50px 0;
  font-weight: bold;
  border-bottom: 1px solid #cccccc;
  margin: 16px 0;
  line-height: 1.5;
  font-size: 20px;
}
h2 {
  margin: 50px 0;
  font-weight: bold;
    margin: 56px 0 40px 0;
    padding: 8px 0 8px 16px;
    border-left: solid 4px #9b8d77;
    background-color: #f0f0f0;
    line-height: 1.5;
    font-size: 20px;
}
h3 {
  margin: 50px 0;
  font-weight: bold;
    font-size: 20px;
    color: #000c15;
    margin: 48px 0 32px 10px;
    padding: 6px 0;
    line-height: 1.5;
    border-bottom: solid 2px #d2d5d9;
}
h4 {
  
  margin: 50px 0;
  font-weight: bold;
  font-size: 18px;
  margin-left: 14px;
  padding: 0.5em 0;
  border-left: 4px solid #7db4e6;
  padding-left: 10px;
  font-size: 18px;
  color: #000c15;
  line-height: 1.5;
}
h5 {
  
  margin: 50px 0;
  font-weight: bold;
  font-size: 18px;
  margin-left: 14px;
  padding: 0.5em 0;
  padding: 0.4em 0.5em;
    color: #494949;
    background: #f4f4f4;
}
h6 {
  
  margin: 50px 0;
  font-weight: bold;
  font-size: 18px;
  margin-left: 14px;
  padding: 0.5em 0;
  color: #999999;
  border-left: 4px solid #c5e1f5;
}
p {
  font-size: 16px;
  margin: 14px 18px 0px 18px;
  line-height: 2.0;
}
span {
  font-style: italic;
}
ol, ul {
  margin-left: 30px;
  padding: 0;
  list-style: none;
}
ul{
  list-style-type: disc;
}
li {
  font-size: 14px;
  margin: 0.5em 0;
  line-height: 2;
  margin-bottom: 16px;
}
a {
  color: #337ab7;
  text-decoration: none;
}
table {
  width: 100%;
  max-width: 100%;
  margin-bottom: 1em;
  border-collapse: collapse;
}
thead {
  color: #ffffff;
  background-color: #337ab7;
}
tbody tr:nth-of-type(odd) {
  background-color: #f9f9f9;
}
tbody tr:hover {
  background-color: #f5f5f5;
}
td {
  padding: 0.75em;
  vertical-align: top;
  border-top: 1px solid #ddd;
}
th {
  padding: 0.75em;
  vertical-align: top;
  border-top: 1px solid #ddd;  
  color: #ffffff;
  font-size: 14px;
  text-align: left;
}
tr {
  color: #555555;
  border-bottom: 1px solid #ddd;
}
td {
  color: #555555;
  font-size: 14px;
}

			
EOF;


    return $default_css;
}



?>